==> kmymoney-5.0.4.tar.xz: kmymoney-5.0.4/kmymoney/plugins/weboob/weboob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@weboob.org",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx"
            }
        ],
        "Description": "Plugin for weboob",
        "Description[ca@valencia]": "Connector pel Weboob",
        "Description[ca]": "Connector pel Weboob",
        "Description[en_GB]": "Plugin for weboob",
        "Description[es]": "Complemento para weboob",
        "Description[fr]": "Module externe pour weboob",
        "Description[gl]": "Complemento para weboob",
        "Description[it]": "Estensione per weboob",
        "Description[nl]": "Plug-in voor weboob",
        "Description[pl]": "Wtyczka dla weboob",
        "Description[pt]": "'Plugin' do Weboob",
        "Description[pt_BR]": "Plugin para weboob",
        "Description[sk]": "Plugin pre weboob",
        "Description[sv]": "Insticksprogram för weboob",
        "Description[uk]": "Додаток weboob",
        "Description[x-test]": "xxPlugin for weboobxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "weboob",
        "License": "GPL",
        "Name": "Weboob",
        "Name[ca@valencia]": "Weboob",
        "Name[ca]": "Weboob",
        "Name[en_GB]": "Weboob",
        "Name[es]": "Weboob",
        "Name[fr]": "Weboob",
        "Name[gl]": "Weboob",
        "Name[it]": "Weboob",
        "Name[nl]": "Weboob",
        "Name[pl]": "Weboob",
        "Name[pt]": "Weboob",
        "Name[pt_BR]": "Weboob",
        "Name[sk]": "Weboob",
        "Name[sv]": "Weboob",
        "Name[uk]": "Weboob",
        "Name[x-test]": "xxWeboobxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney-5.0.7.tar.xz: kmymoney-5.0.7/kmymoney/plugins/weboob/weboob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@weboob.org",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[de]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx"
            }
        ],
        "Description": "Plugin for weboob",
        "Description[ca@valencia]": "Connector pel Weboob",
        "Description[ca]": "Connector pel Weboob",
        "Description[de]": "Modul für Weboob",
        "Description[en_GB]": "Plugin for weboob",
        "Description[es]": "Complemento para weboob",
        "Description[fr]": "Module externe pour weboob",
        "Description[gl]": "Complemento para weboob",
        "Description[it]": "Estensione per weboob",
        "Description[nl]": "Plug-in voor weboob",
        "Description[pl]": "Wtyczka dla weboob",
        "Description[pt]": "'Plugin' do Weboob",
        "Description[pt_BR]": "Plugin para weboob",
        "Description[sk]": "Plugin pre weboob",
        "Description[sv]": "Insticksprogram för weboob",
        "Description[uk]": "Додаток weboob",
        "Description[x-test]": "xxPlugin for weboobxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "weboob",
        "License": "GPL",
        "Name": "Weboob",
        "Name[ca@valencia]": "Weboob",
        "Name[ca]": "Weboob",
        "Name[cs]": "Weboob",
        "Name[de]": "Weboob",
        "Name[en_GB]": "Weboob",
        "Name[es]": "Weboob",
        "Name[fr]": "Weboob",
        "Name[gl]": "Weboob",
        "Name[it]": "Weboob",
        "Name[nl]": "Weboob",
        "Name[pl]": "Weboob",
        "Name[pt]": "Weboob",
        "Name[pt_BR]": "Weboob",
        "Name[sk]": "Weboob",
        "Name[sv]": "Weboob",
        "Name[uk]": "Weboob",
        "Name[x-test]": "xxWeboobxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
